@@ -4,14 +4,14 @@ use warnings;
 
 package Git::Wrapper;
 #ABSTRACT: Wrap git(7) command-line interface
-$Git::Wrapper::VERSION = '0.040';
+$Git::Wrapper::VERSION = '0.043';
 our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
 # https://github.com/genehack/Git-Wrapper/issues/13
 delete $ENV{GIT_PAGER_IN_USE};
 
-use File::pushd;
+use File::chdir;
 use File::Temp;
 use IPC::Open3      qw();
 use Scalar::Util    qw(blessed);
@@ -83,7 +83,7 @@ sub RUN {
   my( @out , @err );
 
   {
-    my $d = pushd $self->dir unless $cmd eq 'clone';
+    local $CWD = $self->dir unless $cmd eq 'clone';
 
     my ($wtr, $rdr, $err);
 
@@ -168,6 +168,14 @@ sub has_git_in_path {
 sub log {
   my $self = shift;
 
+  if ( grep /format=/, @_ ) {
+    die Git::Wrapper::Exception->new(
+      error  => [qw/--format not allowed. Use the RUN() method if you with to use a custom log format./],
+      output => undef,
+      status => 255 ,
+    );
+  }
+
   my $opt  = ref $_[0] eq 'HASH' ? shift : {};
   $opt->{no_color}         = 1;
   $opt->{pretty}           = 'medium';
@@ -388,7 +396,7 @@ Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.040
+version 0.043
 
 =head1 SYNOPSIS
 
@@ -593,7 +601,9 @@ you want ANSI color highlighting, you'll need to bypass via the RUN() method
   my @logs = $git->log;
 
 Instead of giving back an arrayref of lines, the C<log> method returns a list
-of C<Git::Wrapper::Log> objects. They have four methods:
+of C<Git::Wrapper::Log> objects.
+
+There are four methods in a C<Git::Wrapper::Log> objects:
 
 =over
 
@@ -607,6 +617,18 @@ of C<Git::Wrapper::Log> objects. They have four methods:
 
 =back
 
+=head3 Custom log formats
+
+C<log> will throw an exception if it is passed the C<--format> option. The
+reason for this has to do with the fact that the parsing of the full log
+output into C<Git::Wrapper::Log> objects assumes the default format provided
+by `git` itself. Passing C<--format> to the underlying `git log` method affects
+this assumption and the output is no longer able to be processed as intented.
+
+If you wish to specify a custom log format, please use the L<RUN> method
+directly.  The caller will be supplied with the full log output. From there,
+the caller may process the output as it wishes.
+
 =head2 has_git_in_path
 
 This method returns a true or false value indicating if there is a 'git'
@@ -773,6 +795,9 @@ values, and then a list of any other arguments.
     # while 'RUN('log')' returns an array of chomped lines
     my @log_lines = $git->RUN('log');
 
+    # getting the full of commit SHAs via `git log` by using the '--format' option
+    my @log_lines = $git->RUN('log', '--format=%H');
+
 =head2 ERR
 
 After a command has been run, this method will return anything that was sent
